import React, {SVGProps} from "react";
import IconLoading from "../icons/IconLoading";
import './btn.less'
import classNames from "../../utils/classnames";

export type ButtonProp = {
    children?: React.ReactNode;
    loading?: boolean
    disabled?: boolean
    type?: "primary" | "default"
    htmlType?: "button" | "submit"
    block?: boolean
} & JSX.IntrinsicAttributes & SVGProps<HTMLButtonElement>

const Button: React.FC<ButtonProp> = (props) => {
    return (
        <button
            disabled={props.disabled}
            type={props.htmlType || 'button'}
            className={classNames('btn',props.className, `btn-${props.type || 'default'}`, {'btn-block': props.block})}
            onClick={props.onClick}
        >
            {props.loading && <span className="btn-loading">
                <span role="img" aria-label="loading" className="ani-loading btn-loading-icon">
                    <IconLoading/>
                </span>
            </span>}
            <span>{props.children}</span>
        </button>
    );
}
export default Button;