import React from "react";
import './vip.less'
import IconClose from "../icons/IconClose";
import {useCountDown, useSetState} from "ahooks";
import classNames from "../../utils/classnames";
import Button from "../Button";
import IconCheck from "../icons/IconCheck";

export type VipProps = {
    onClose: (opened: boolean) => void;
}
const levels = [
    {
        id: 1,
        title: '年会员',
        price: 198,
        originPrice: 218,
        remark: '最划算',
        addition: '最多人购买',
        countDown: Date.now() + 3600 * 24 * 1000
    },
    {
        id: 2,
        title: '季会员',
        price: 98,
        originPrice: 123,
        remark: '1.00/天',
        addition: '',
        countDown: 0
    },
    {
        id: 3,
        title: '月会员',
        price: 68,
        originPrice: 98,
        remark: '2.27/天',
        addition: '',
        countDown: 0
    }
]
const Vip: React.FC<VipProps> = (props) => {
    // 当前状态
    const [state, setState] = useSetState({
        selectedIndex: 0
    })
    // 倒计时
    const [_] = useCountDown({
        targetDate: levels[0].countDown
    })
    return (<div className="vip-wrapper-root">
        <div className="vip-mask mask-wrapper"></div>
        <div className="vip-wrapper flex-center view-full">
            <div className="vip-dialog dialog">
                <div className="close" onClick={() => props.onClose(false)}>
                    <IconClose/>
                </div>
                <h2 className="title">会员中心</h2>
                <div className="intro">
                    <div className="flex-center">
                        <IconCheck/>
                        <p>畅享更多高级功能</p>
                    </div>
                    <div className="flex-center">
                        <IconCheck/>
                        <p>10000+用户已开通</p>
                    </div>
                </div>
                <div className="features">
                    <div className="feature-item">
                        <div className="name">无限畅聊</div>
                        <div className="desc">不限制收发次数</div>
                    </div>
                    <div className="feature-item">
                        <div className="name">超低延迟</div>
                        <div className="desc">低延迟快速恢复</div>
                    </div>
                    <div className="feature-item">
                        <div className="name">独享接口</div>
                        <div className="desc">畅快对话</div>
                    </div>
                    <div className="feature-item">
                        <div className="name">专属客服</div>
                        <div className="desc">1对1客服</div>
                    </div>
                </div>
                <div className="levels">
                    {levels.map((l, index) => (
                        <div
                            key={index}
                            onClick={() => setState({selectedIndex: index})}
                            className={classNames('level-item', {selected: state.selectedIndex === index})}
                        >
                            {l.addition && <div className="addition-desc">{l.addition}</div>}
                            <div className="level-title">{l.title}</div>
                            <div className="level-price"><span className="unit">￥</span><span
                                className="price">{l.price}</span></div>
                            <div className="level-origin-price"><span className="unit">￥</span><span
                                className="price">{l.originPrice}</span></div>
                            <div className="remark">
                                {/*{l.countDown > 0 ? (`还剩${f.hours}:${f.minutes}:${f.seconds}后结束`) : l.remark}*/}
                                {l.remark}
                            </div>
                        </div>))}
                </div>
                <div className="button">
                    <Button type="primary" block>立即解锁</Button>
                </div>
            </div>
        </div>
    </div>)
}
export default Vip;