import axios from 'axios';

export interface APIResponse<T> {
    code: number;
    data?: T;
    message: string;
}

// const baseURL = APP_CONFIG.API_PREFIX;
// const FORM_FORMAT = 'application/x-www-form-urlencoded';
const JSON_FORMAT = 'application/json';
export type RequestMethod = 'get' | 'post' | 'put' | 'delete'

const Axios = axios.create({
    baseURL: APP_CONFIG.API_PREFIX,
    timeout: 20000, // 设置超时时长
    headers: {
        'Content-Type': JSON_FORMAT
    }
})


// 请求前拦截
Axios.interceptors.request.use(config => {
    const token = localStorage.getItem(APP_CONFIG.LOGIN_TOKEN_KEY)
    if (token) {
        config.headers['token'] = token;
    }
    return config
}, err => {
    return Promise.reject(err)
})
//
// // 返回后拦截
// Axios.interceptors.response.use(res => {
//     return res
// }, err => {
//     if (err.message === 'Network Error') {
//         err.message = '网络连接异常！';
//     } else if (err.code === 'ECONNABORTED') {
//         err.message = '请求超时，请重试';
//     }
//
//     return Promise.reject(err)
// })

export function request<T>(url: string, method: RequestMethod, data: any = null) {
    return new Promise<T>((resolve, reject) => {
        Axios.request<APIResponse<T>>({
            url,
            method,
            data,
        }).then(res => {
            if (res.status != 200) {
                reject(Error("服务异常,请稍后再试"))
                return;
            }
            const {code, message, data} = res.data
            if (code == 0) {
                resolve(data as any as T)
            } else {
                reject(Error(message))
            }
        })
    })
}

export function post<T>(url: string, data: any) {
    return request<T>(url, 'post', data)
}

export function get<T>(url: string, data: any = {}) {
    return request<T>(url, 'get', data)
}
